@@ -4,11 +4,12 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from pathlib import Path
 from typing import Dict, List, Optional
 
-from contracts import contract
-from ymplayer import Player
+from ycontract import prev_contract
 
+from exclock.sound_player import Player
 from exclock.util import get_real_sound_filename, get_time_delta_from_str, notify_all
 
 DEFAULT_TITLE = "ExClock"
@@ -41,17 +42,20 @@ class Sound:
     def __post_init__(self) -> None:
         self.sound_filename = get_real_sound_filename(self.sound_filename)
 
+    @prev_contract(lambda self: Path(self.sound_filename).exists())
     def play(self):
         p = Player(self.sound_filename)
         p.play()
 
     @classmethod
+    @prev_contract(lambda json: "message" in json and "sound_filename" in json)
     def from_dict(cls, json: dict) -> Sound:
         return Sound(
             message=json["message"],
             sound_filename=get_real_sound_filename(json.get("sound_filename")),
         )
 
+    @prev_contract(lambda self, other: isinstance(other, self.__class__))
     def __eq__(self, other) -> bool:
         return self.message == other.message and self.sound_filename == other.sound_filename
 
@@ -66,7 +70,7 @@ class ClockTimer:
     def sorted_sounds(self) -> Dict[int, Sound]:
         return {sec: self.sounds[sec] for sec in sorted(self.sounds)}
 
-    @contract(count=">=0")
+    @prev_contract(lambda count: count >= 0)
     def run_once(self, count: int) -> None:
         sounds = self.sorted_sounds
 
@@ -96,6 +100,8 @@ class ClockTimer:
                 count += 1
 
     @classmethod
+    @prev_contract(lambda json: "sounds" in json)
+    @prev_contract(lambda json: isinstance(json, dict))
     def from_dict(cls, json: dict) -> ClockTimer:
         sounds = {}
         for sec, sound in json["sounds"].items():
