@@ -8,8 +8,9 @@ from pathlib import Path
 from sys import exit, stderr
 from typing import List, Optional
 
-from ymplayer import Player
+from ycontract import ret_contract
 
+from exclock.sound_player import Player
 from exclock.util import (
     DEFAULT_RING_FILENAME,
     convert_specific_time_to_time_delta,
@@ -22,6 +23,7 @@ from exclock.util import (
 )
 
 
+@ret_contract(lambda res: res is None or res >= 0)
 def get_spend_sec(time_: str) -> Optional[int]:
     if is_specific_time_str(time_):
         now_ = datetime.now()
